Hello there! 

Thank you for the checking out `hiwenet`, and for your interest in contributing. Please check the following guidelines for contributing: http://contribution-guide-org.readthedocs.io/

You could contribute in the areas, including but not limited to:
 * identifying any bugs by focusing on the areas of hiwenet that you have expertise in 
    * write unit tests or property tests to assert its advertised functionality
 * installing and using it to ensure it works as advertised (and fix it otherwise)
 * sharpening or improving the focus of the repo in general
 * improving, clarifying and adding documentation
 * propose interesting, popular and exciting use cases that this package could support to further multiply its value
 * improving code base in terms of modularity
   * building an API-like interface for programmatic access, 
   * ideas for integration with other use cases
 
 Thank you again for your interest. Appreciate your contribution in all its forms.
 
 *Under construction*
